@@ -119,8 +119,8 @@ void NotesManager::slotCheckAlarm()
     NoteShared::NoteSharedGlobalConfig::self()->setAlarmsLastChecked(now);
 
     Akonadi::Item::List lst;
-    for (const Akonadi::Item &item : qAsConst(mListItem)) {
-        const auto *attrAlarm = item.attribute<NoteShared::NoteAlarmAttribute>();
+    for (const Akonadi::Item &item : std::as_const(mListItem)) {
+        const auto attrAlarm = item.attribute<NoteShared::NoteAlarmAttribute>();
         if (attrAlarm) {
             if (attrAlarm->dateTime() < QDateTime::currentDateTime()) {
                 lst.append(item);
