@@ -25,7 +25,7 @@ NoteLockAttribute *NoteLockAttribute::clone() const
 
 void NoteLockAttribute::deserialize(const QByteArray &data)
 {
-    Q_UNUSED(data);
+    Q_UNUSED(data)
 }
 
 QByteArray NoteLockAttribute::serialized() const
@@ -35,7 +35,7 @@ QByteArray NoteLockAttribute::serialized() const
 
 QByteArray NoteLockAttribute::type() const
 {
-    //We can't change this name!
+    // We can't change this name!
     static const QByteArray sType("KJotsLockAttribute");
     return sType;
 }
