@@ -16,21 +16,17 @@
 #include <KAcceleratorManager>
 #include <KCheckableProxyModel>
 #include <KLocalizedString>
+#include <KPluginFactory>
 #include <KSharedConfig>
 
 #include <QCheckBox>
 #include <QTreeView>
 #include <QVBoxLayout>
 
-extern "C" {
-Q_DECL_EXPORT KCModule *create_knotessummary(QWidget *parent, const char *)
-{
-    return new KCMKNotesSummary(parent);
-}
-}
+K_PLUGIN_CLASS_WITH_JSON(KCMKNotesSummary, "kcmknotessummary.json")
 
-KCMKNotesSummary::KCMKNotesSummary(QWidget *parent)
-    : KCModule(parent)
+KCMKNotesSummary::KCMKNotesSummary(QWidget *parent, const QVariantList &args)
+    : KCModule(parent, args)
 {
     initGUI();
 
@@ -40,12 +36,12 @@ KCMKNotesSummary::KCMKNotesSummary(QWidget *parent)
 
     load();
 
-    KAboutData *about = new KAboutData(QStringLiteral("kcmknotessummary"),
-                                       i18n("kcmknotessummary"),
-                                       QString(),
-                                       i18n("Notes Summary Configuration Dialog"),
-                                       KAboutLicense::GPL,
-                                       i18n("Copyright © 2013-2021 Laurent Montel <montel@kde.org>"));
+    auto about = new KAboutData(QStringLiteral("kcmknotessummary"),
+                                i18n("kcmknotessummary"),
+                                QString(),
+                                i18n("Notes Summary Configuration Dialog"),
+                                KAboutLicense::GPL,
+                                i18n("Copyright © 2013-2021 Laurent Montel <montel@kde.org>"));
     about->addAuthor(ki18n("Laurent Montel").toString(), QString(), QStringLiteral("montel@kde.org"));
     setAboutData(about);
 }
@@ -103,3 +99,5 @@ void KCMKNotesSummary::defaults()
 {
     Q_EMIT changed(true);
 }
+
+#include "kcmknotessummary.moc"
